import { MdButtonModule, MdCardModule, MdIconModule, MdMenuModule, MdProgressSpinnerModule } from '@angular/material';
import { CommonModule } from '@angular/common';
import { FlexLayoutModule } from '@angular/flex-layout';
import { Component, ContentChildren, Injectable, Input, NgModule, ViewChild } from '@angular/core';
import { NguiOverlayManager, NguiOverlayModule } from '@ngui/overlay';
import { Observable, Subject } from 'rxjs';

var NgxMaterialStateComponent = /** @class */ (function () {
    function NgxMaterialStateComponent() {
    }
    /**
     * @return {?}
     */
    NgxMaterialStateComponent.prototype.ngOnInit = function () {
        this.state = {
            name: this.stateName,
            linkName: this.linkName,
            icon: this.icon
        };
    };
    NgxMaterialStateComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngx-md-window-state',
                    template: "\n    <div *ngIf=\"state.isActive\">\n      <ng-content></ng-content>\n    </div>\n  "
                },] },
    ];
    /**
     * @nocollapse
     */
    NgxMaterialStateComponent.ctorParameters = function () { return []; };
    NgxMaterialStateComponent.propDecorators = {
        'linkName': [{ type: Input },],
        'stateName': [{ type: Input },],
        'icon': [{ type: Input },],
    };
    return NgxMaterialStateComponent;
}());

var NgxMaterialWindowService = /** @class */ (function () {
    function NgxMaterialWindowService() {
        this.overlaySubject = new Subject();
    }
    /**
     * @param {?} cb
     * @return {?}
     */
    NgxMaterialWindowService.prototype.setOverlayFunction = function (cb) {
        this.showOverlay = cb;
    };
    /**
     * @return {?}
     */
    NgxMaterialWindowService.prototype.getOverlaySubject = function () {
        return this.overlaySubject;
    };
    NgxMaterialWindowService.decorators = [
        { type: Injectable },
    ];
    /**
     * @nocollapse
     */
    NgxMaterialWindowService.ctorParameters = function () { return []; };
    return NgxMaterialWindowService;
}());

var NgxMaterialWindowComponent = /** @class */ (function () {
    /**
     * @param {?} overlayManager
     * @param {?} windowService
     */
    function NgxMaterialWindowComponent(overlayManager, windowService) {
        this.overlayManager = overlayManager;
        this.windowService = windowService;
    }
    /**
     * @return {?}
     */
    NgxMaterialWindowComponent.prototype.ngOnInit = function () {
        this.overlayId = Math.random().toString();
        this.windowService.setOverlayFunction(this.showOverlay.bind(this));
    };
    /**
     * @return {?}
     */
    NgxMaterialWindowComponent.prototype.ngAfterContentInit = function () {
        var /** @type {?} */ click$ = Observable.fromEvent(this.reloadBtn._getHostElement(), 'click');
        var /** @type {?} */ subject$ = this.windowService.getOverlaySubject();
        click$.subscribe(subject$);
        this.overlaySubject = subject$.subscribe(this.showOverlay.bind(this));
        this.stateComponents.forEach(function (cmp, index$$1) { return (cmp.state.isActive = index$$1 === 0 ? true : false); });
    };
    /**
     * @return {?}
     */
    NgxMaterialWindowComponent.prototype.ngOnDestroy = function () {
        this.overlaySubject.unsubscribe();
    };
    /**
     * @param {?} stateName
     * @return {?}
     */
    NgxMaterialWindowComponent.prototype.setActiveState = function (stateName) {
        this.stateComponents.forEach(function (cmp) { return (cmp.state.isActive = cmp.state.name === stateName ? true : false); });
    };
    /**
     * @param {?=} event
     * @return {?}
     */
    NgxMaterialWindowComponent.prototype.showOverlay = function (event) {
        this.spinnerWrap.nativeElement.style.height = this.card.nativeElement.offsetHeight + "px";
        this.overlayManager.open(this.overlayId, event);
    };
    NgxMaterialWindowComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngx-md-window',
                    template: "\n    <div class=\"ngx-md-window\" #card>\n      <md-card>\n        <div class=\"spinner-wrap\" #spinnerWrap>\n          <div [id]=\"overlayId\" ngui-overlay-position=\"top center\">\n            <md-spinner class=\"spinner\"></md-spinner>\n          </div>\n        </div>\n        <md-card-header fxLayout=\"row\" fxLayoutAlign=\"space-between\" class=\"ngx-md-window-header\">\n          <md-card-title style=\"margin-bottom: 0;\">\n            <h4 class=\"ngx-md-window-header-title\">{{ title }}</h4>\n          </md-card-title>\n          <div fxLayout=\"row\">\n            <button md-icon-button (click)=\"showOverlay($event)\" #reloadBtn>\n              <md-icon>replay</md-icon>\n            </button>\n            <div *ngIf=\"stateComponents.length > 0\">\n              <button\n                md-icon-button\n                [mdMenuTriggerFor]=\"menu\">\n                <md-icon>more_vert</md-icon>\n              </button>\n              <md-menu #menu=\"mdMenu\">\n                <button md-menu-item *ngFor=\"let cmp of stateComponents\" (click)=\"setActiveState(cmp.state.name)\">\n                  <md-icon *ngIf=\"cmp.state.icon\">{{ cmp.state.icon }}</md-icon>\n                  <span>{{ cmp.state.linkName }}</span>\n                </button>\n              </md-menu>\n            </div>\n          </div>\n        </md-card-header>\n        <md-card-content style=\"padding: 8px\">\n          <ng-content></ng-content>\n        </md-card-content>\n      </md-card>\n    </div>\n  ",
                    styles: [".spinner-wrap { position: absolute; top: 0; left: 0; width: 100%; z-index: 2; } .spinner { width: 35px; height: 35px; background-color: #fff; border: 5px solid #fff; border-radius: 50%; margin-top: 40px; } .ngx-md-window > md-card { padding: 0; } .ngx-md-window-header { color: rgba(0, 0, 0, 0.54); background-color: rgba(0, 0, 0, 0.03); } .ngx-md-window-header-title { margin-top: 10px; margin-bottom: 0; } "],
                    providers: [NgxMaterialWindowService]
                },] },
    ];
    /**
     * @nocollapse
     */
    NgxMaterialWindowComponent.ctorParameters = function () { return [
        { type: NguiOverlayManager, },
        { type: NgxMaterialWindowService, },
    ]; };
    NgxMaterialWindowComponent.propDecorators = {
        'title': [{ type: Input },],
        'stateComponents': [{ type: ContentChildren, args: [NgxMaterialStateComponent,] },],
        'card': [{ type: ViewChild, args: ['card',] },],
        'spinnerWrap': [{ type: ViewChild, args: ['spinnerWrap',] },],
        'reloadBtn': [{ type: ViewChild, args: ['reloadBtn',] },],
    };
    return NgxMaterialWindowComponent;
}());

var NgxMaterialWindowModule = /** @class */ (function () {
    function NgxMaterialWindowModule() {
    }
    NgxMaterialWindowModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        MdCardModule,
                        MdIconModule,
                        MdMenuModule,
                        MdButtonModule,
                        MdProgressSpinnerModule,
                        NguiOverlayModule
                    ],
                    declarations: [
                        NgxMaterialWindowComponent,
                        NgxMaterialStateComponent
                    ],
                    exports: [
                        NgxMaterialWindowComponent,
                        NgxMaterialStateComponent
                    ]
                },] },
    ];
    /**
     * @nocollapse
     */
    NgxMaterialWindowModule.ctorParameters = function () { return []; };
    return NgxMaterialWindowModule;
}());

export { NgxMaterialWindowModule, NgxMaterialWindowComponent, NgxMaterialStateComponent, NgxMaterialWindowService };
